@@ -1,50 +1,31 @@
 package MySQL::Easy;
 
-# $Id: Easy.pm,v 1.3 2004/12/29 13:59:20 jettero Exp $
+# $Id: Easy.pm,v 1.18 2002/06/05 00:01:36 jettero Exp $
 # vi:fdm=marker fdl=0:
 
 use strict;
 use warnings;
 use Carp;
-use AutoLoader;
 
 use DBI;
 
-our $VERSION = "1.25.1";
-use vars qw($AUTOLOAD);
+our $VERSION = "1.14";
 
 return 1;
 
-# AUTOLOAD {{{
-sub AUTOLOAD {
-    my $this = shift;
-    my $sub  = $AUTOLOAD;
-
-    $sub = $1 if $sub =~ m/::(\w+)$/;
-
-    my $e = $SIG{__WARN__}; $SIG{__WARN__} = sub {};
-    my $r = $this->handle->$sub( @_ ) or croak "MySQL::Easy AUTOLOAD of $sub failed: " . $this->errstr;
-    $SIG{__WARN__} = $e;
-
-    return $r;
-}
-# }}}
-
 # new {{{
 sub new { 
     my $this  = shift;
 
     $this = bless {}, $this;
 
-    $this->{dbase} = shift; croak "dbase = '$this->{dbase}'?" unless $this->{dbase};
-    $this->{dbh} = $this->{dbase} if ref($this->{dbase}) eq "DBI::db";
+    $this->{dbase} = shift;
     $this->{trace} = shift;
 
-    $this->{dbh}->trace( $this->{trace} ) if $this->{dbh};
-
     return $this;
 }
 # }}}
+
 # do {{{
 sub do {
     my $this = shift; return unless @_;
@@ -76,7 +57,7 @@ sub unlock {
 sub ready {
     my $this = shift;
 
-    return $this->handle->prepare( @_ );
+    return $this->handle->prepare(@_);
 }
 # }}}
 # firstcol {{{
@@ -87,62 +68,49 @@ sub firstcol {
     return $this->handle->selectcol_arrayref($query, undef, @_);
 }
 # }}}
-# thread_id {{{
-sub thread_id {
-    my $this = shift;
+# trace {{{
+sub trace {
+    my $this  = shift;
 
-    return $this->handle->{mysql_thread_id};
+    $this->{trace} = shift;
+    $this->handle->trace($this->{trace});
 }
 # }}}
-# last_insert_id {{{
-sub last_insert_id {
-    my $this = shift;
-
-    # return $this->firstcol("select last_insert_id()")->[0];
-    return $this->handle->{mysql_insertid};
-}
-# }}}
-# errstr (needs to be here, called from AUTOLOAD) {{{
+# errstr {{{
 sub errstr {
     my $this = shift;
 
     return $this->handle->errstr;
 }
 # }}}
-# trace (needs to be here, called from AUTOLOAD) {{{
-sub trace {
+# last_insert_id {{{
+sub last_insert_id {
     my $this = shift;
 
-    $this->handle->trace( @_ );
+    return $this->firstcol("select last_insert_id()")->[0];
 }
 # }}}
-# DESTROY {{{
+
 sub DESTROY {
     my $this = shift;
 
     $this->{dbh}->disconnect if $this->{dbh};
 }
-# }}}
+
 # handle {{{
 sub handle {
     my $this = shift;
 
-    return $this->{dbh} if defined($this->{dbh}) and $this->{dbh}->ping;
+    if(not $this->{dbh}) {
+        ($this->{user}, $this->{pass}) = $this->unp unless $this->{user} and $this->{pass};
 
-    ($this->{user}, $this->{pass}) = $this->unp unless $this->{user} and $this->{pass};
+        $this->{host}  = "localhost" unless $this->{host};
+        $this->{dbase} =      "test" unless $this->{dbase};
+        $this->{trace} =           0 unless $this->{trace};
 
-    $this->{host}  = "localhost" unless $this->{host};
-    $this->{port}  =      "3306" unless $this->{port};
-    $this->{dbase} =      "test" unless $this->{dbase};
-    $this->{trace} =           0 unless $this->{trace};
-
-    $this->{dbh} = DBI->connect("DBI:mysql:$this->{dbase}:host=$this->{host}:port=$this->{port}:mysql_compression=1", 
-        $this->{user}, $this->{pass});
-
-    croak "fail'd to generate connection (db=$this->{dbase}, ho=$this->{host}, us=$this->{user}): " . DBI->errstr 
-        unless $this->{dbh};
-
-    $this->{dbh}->trace($this->{trace});
+        $this->{dbh} = DBI->connect("DBI:mysql:$this->{dbase}:$this->{host}", $this->{user}, $this->{pass});
+        $this->{dbh}->trace($this->{trace}) if $this->{dbh};
+    }
 
     return $this->{dbh};
 }
@@ -168,17 +136,12 @@ sub unp {
     return ($user, $pass);
 }
 # }}}
+
 # set_host set_user set_pass {{{
 sub set_host { 
     my $this = shift;
 
-    $this->{host} = shift;
-}
-
-sub set_port { 
-    my $this = shift;
-
-    $this->{port} = shift;
+    $this->{host} = shift 
 }
 
 sub set_user { 
@@ -193,19 +156,6 @@ sub set_pass {
     $this->{pass} = shift;
 }
 # }}}
-# bind_execute {{{
-sub bind_execute {
-    my $this = shift;
-    my $sql  = shift;
-
-    my $sth = $this->ready($sql);
-
-    $sth->execute            or return undef;
-    $sth->bind_columns( @_ ) or return undef;
-
-    return $sth;
-}
-# }}}
 
 __END__
 # Below is stub documentation for your module. You better edit it!
@@ -218,22 +168,18 @@ MySQL::Easy - Perl extension to make your base code kinda pretty.
 
   use MySQL::Easy;
 
-  my $trace = 0; # the trace arg is optional
-  my $dbo = new MySQL::Easy("stocks", $trace);
-
-  #  This is NEW (and totally untested):
-  #  $dbo = new MySQL::Easy($existing_DBI_dbh, $trace);
+  my $dbo = new MySQL::Easy("stocks");
 
   my $symbols = $dbo->firstcol(
       qq( select symbol from ohlcv where symbol != ?),
       "msft"
   );
 
-  for my $s (@$symbols) {
+  for(@$symbols) {
       my $q = $dbo->ready("select * from ohlcv where symbol=?");
       my @a;
 
-      $q->execute($s)
+      execute $q;
       print "@a" while @a = fetchrow_array $q;
   }
 
@@ -285,8 +231,7 @@ MySQL::Easy - Perl extension to make your base code kinda pretty.
        # thread...  Same as a $sth->errstr.  It's actually
        # described in DBI
 
-   $dbo->set_host($h); $dbo->set_port($p); 
-   $dbo->set_user($U); $dbo->set_pass($p);
+   $dbo->set_host($h); $dbo->set_user($U); $dbo->set_pass($p);
        # The first time you do a do/ready/firstcol/etc,
        # MySQL::Easy connects to the database.  You may use these
        # set functions to override values found in your ~/.my.cnf
@@ -296,19 +241,6 @@ MySQL::Easy - Perl extension to make your base code kinda pretty.
        # a fatal error if the user or pass is false and the
        # ~/.my.cnf cannot be opened.
 
-   my $table;
-   my $sth = $dbo->bind_execute("show tables", \( $table ) );
-       # This was Josh's idea... And a good one.
-
-   die $dbo->errstr unless $sth;  
-       # bind_execute returns undef if either the bind
-       # or execute phases fail.
-
-   print "$table\n" while fetch $sth;
-
-   # Anything from the DBI.pm manpage will work with the
-   # $dbo (thanks to an AUTOLOAD function).
-
 =head1 AUTHOR
 
 Jettero Heller <japh@voltar-confed.org>
@@ -320,26 +252,6 @@ Jettero Heller <japh@voltar-confed.org>
    Half the fun of releasing this stuff is knowing 
    that people use it.
 
-=head1 THANKS
-
-    For bugs and ideas: Josh Rabinowitz <joshr-cpan@joshr.com>
-
-=head1 COPYRIGHT
-
-    GPL!  I included a gpl.txt for your reading enjoyment.
-
-    Though, additionally, I will say that I'll be tickled if you were to
-    include this package in any commercial endeavor.  Also, any thoughts to
-    the effect that using this module will somehow make your commercial
-    package GPL should be washed away.
-
-    I hereby release you from any such silly conditions.
-
-    This package and any modifications you make to it must remain GPL.  Any
-    programs you (or your company) write shall remain yours (and under
-    whatever copyright you choose) even if you use this package's intended
-    and/or exported interfaces in them.
-
 =head1 SEE ALSO
 
 perl(1), DBI(3)
